@@ -1,9 +1,40 @@
-
 # concordance - given a carrel and a word, output rudimentary keyword-in-context
 
 # require
 from rdr import *
 
+# create and/or get the NTTK model
+def getNLTKText( carrel ) :
+
+	# configure
+	MODEL = 'reader.nltk'
+
+	# require
+	from nltk import Text, word_tokenize
+	from os   import path, stat
+	import    pickle
+	
+	# initialize
+	localLibrary = configuration( 'localLibrary' )
+	file         = localLibrary/carrel/ETC/MODEL
+
+	# check to see if we've previously been here
+	if path.exists( file ) :
+	
+		# read the model
+		with open( file, 'rb' ) as handle : model = pickle.load( handle )	
+			
+	else :
+
+		# create the model and save it for future use
+		corpus = localLibrary/carrel/ETC/CORPUS
+		model  = Text( word_tokenize( open( corpus ).read( ) ) )
+		with open( file, 'wb' ) as handle : pickle.dump( model, handle )
+
+	# return the model
+	return( model )
+
+
 @click.command( options_metavar='[<options>]' )
 @click.option('-w', '--width', default=80, help='number of characters in each line of output')
 @click.option('-l', '--lines', default=999, help='number of lines of text to output')
@@ -31,14 +62,12 @@ def concordance( carrel, query, width, lines ) :
 	checkForPunkt()
 	
 	# initialize, read, and normalize; ought to save the result for future use
-	localLibrary = configuration( 'localLibrary' )
-	corpus       = localLibrary/carrel/ETC/CORPUS
-	text         = Text( word_tokenize( open( corpus ).read( ) ) )
+	model = getNLTKText( carrel )
 					
 	# split query into a list, conditionally
 	if ' ' in query : query = query.split( ' ' )
 		
 	# do the work and output
-	lines = text.concordance_list( query, width=width, lines=lines )
+	lines = model.concordance_list( query, width=width, lines=lines )
 	for line in lines : click.echo( line.line )
 	
\ No newline at end of file
